# ebbp : Empirical Bayes on the Binomial in Python

I have tried to implement the R package __ebbr__ (Empirical Bayes on the Binomial in R, by David Robinson) in Python. 
Please visit http://varianceexplained.org/r/ebbr-package/ to get the idea about what the package does and https://github.com/dgrtwo/ebbr for the R implementation

## Usage so far
Only the functions for fitting a Beta prior from data, computing shrinkage estimates, credible intervals and some plots have been done. 


## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.


## License
[MIT](https://choosealicense.com/licenses/mit/)
